@@ -18,22 +18,18 @@
 
 """Lazy ZIP over HTTP"""
 
-__version__ = '0.0.1'
+__version__ = '0.0.2'
 __all__ = ['Lazip']
 
 from bisect import bisect_left, bisect_right
 from contextlib import contextmanager
 from tempfile import NamedTemporaryFile
-from typing import Dict, Iterator, List, Optional, Tuple
+from typing import Any, Dict, Iterator, List, Optional, Tuple
 from zipfile import BadZipFile, ZipFile
 
-from pip._internal.network.utils import response_chunks
-from pip._internal.utils.wheel import pkg_resources_distribution_for_wheel
 from requests import Session
 from requests.models import CONTENT_CHUNK_SIZE, Response
 
-HEADERS: Dict[str, str] = {'Accept-Encoding': 'identity'}
-
 
 def init_range(stop: int, size: int) -> Iterator[Tuple[int, int]]:
     """Return an iterator of intervals to fetch a file reversedly."""
@@ -54,7 +50,7 @@ class Lazip:
 
     def __init__(self, session: Session, url: str,
                  chunk_size: int = CONTENT_CHUNK_SIZE) -> None:
-        head = session.head(url, headers=HEADERS)
+        head = session.head(url)
         head.raise_for_status()
         assert head.status_code == 200
         self.session, self.url, self.chunk_size = session, url, chunk_size
@@ -69,15 +65,15 @@ class Lazip:
         self.file.__enter__()
         return self
 
-    def __exit__(self, *exc) -> Optional[bool]:
+    def __exit__(self, *exc: Any) -> Optional[bool]:
         return self.file.__exit__(*exc)
 
     @property
-    def name(self):
+    def name(self) -> str:
         """File name."""
         return self.file.name
 
-    def seekable(self):
+    def seekable(self) -> bool:
         """Return whether random access is supported, which is True."""
         return True
 
@@ -93,7 +89,7 @@ class Lazip:
         finally:
             self.seek(pos)
 
-    def check_zip(self, range_request: bool):
+    def check_zip(self, range_request: bool) -> None:
         """Check and download until the file is a valid ZIP."""
         if not range_request:
             end = self.length - 1
@@ -104,17 +100,16 @@ class Lazip:
             self.download(start, end)
             with self.stay():
                 try:
-                    ZipFile(self)
+                    ZipFile(self)   # type: ignore
                 except BadZipFile:
                     pass
                 else:
                     break
 
     def stream_response(self, start: int, end: int,
-                        base_headers: Dict[str, str] = HEADERS) -> Response:
+                        base_headers: Dict[str, str] = {}) -> Response:
         """Return HTTP response to a range request from start to end."""
-        headers = {'Range': f'bytes={start}-{end}'}
-        headers.update(base_headers)
+        headers = {'Range': f'bytes={start}-{end}', **base_headers}
         return self.session.get(self.url, headers=headers, stream=True)
 
     def merge(self, start: int, end: int,
@@ -128,15 +123,15 @@ class Lazip:
             right (int): Index after last overlapping downloaded data
         """
         lslice, rslice = self.left[left:right], self.right[left:right]
-        i = start = min(start, min(lslice, default=start))
-        end = min(end, min(rslice, default=end))
+        i = start = min([start, *lslice[:1]])
+        end = max([end, *rslice[-1:]])
         for j, k in zip(lslice, rslice):
             if j > i: yield i, j-1
             i = k + 1
         if i <= end: yield i, end
         self.left[left:right], self.right[left:right] = [start], [end]
 
-    def download(self, start: int, end: int):
+    def download(self, start: int, end: int) -> None:
         """Download bytes from start to end inclusively."""
         with self.stay():
             i, j = bisect_left(self.right, start), bisect_right(self.left, end)
@@ -144,7 +139,8 @@ class Lazip:
                 response = self.stream_response(start, end)
                 response.raise_for_status()
                 self.seek(start)
-                for chunk in response_chunks(response, self.chunk_size):
+                for chunk in response.raw.stream(self.chunk_size,
+                                                 decode_content=False):
                     self.file.write(chunk)
 
     def read(self, size: int = -1) -> bytes:
@@ -176,12 +172,3 @@ class Lazip:
     def close(self) -> None:
         """Close the file."""
         self.file.close()
-
-
-if __name__ == '__main__':
-    url = ('https://files.pythonhosted.org/packages/17/d9/'
-           'ff8955ce17c080c956cd5eed9c2da4de139d5eeabb9f9ebf2d981acef31d/'
-           'brutalmaze-0.9.2-py3-none-any.whl')
-    with Lazip(Session(), url) as wheel:
-        print(pkg_resources_distribution_for_wheel(
-            ZipFile(wheel), 'brutalmaze', wheel.name).requires())
